VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "clsPrettyPrint"
Attribute VB_Creatable = True
Attribute VB_Exposed = True
'*********************************************************************
' PRETTYPR.CLS: Reads a Visual Basic file, and displays a formatted
'               copy in Microsoft Word 6.0 or 7.0.
'*********************************************************************
Option Explicit
Option Compare Text
'*********************************************************************
' Private Member Variables
'*********************************************************************
Private ColorDeclare%, ColorComment%, ColorFunction%
Private ColorSub%, ColorContinueChar%, ColorDefault%
Private Word As Object, SourceFile As Integer
Private DocFileName As String, ErrValue%, bRestore As Boolean
'*********************************************************************
' Private Member Constants
'*********************************************************************
Private Const FIND_CONTINUE_CHAR = " _"
Private Const FIND_COMMENT = "'"
Private Const FIND_DECLARE = "Declare"
Private Const FIND_FUNCTION = "Function"
Private Const FIND_PROPERTY = "Property"
Private Const FIND_SUB = "Sub"
'*********************************************************************
' Private Member Color Constants
'*********************************************************************
Private Const wordAutomatic = 0
Private Const wordBlack = 1
Private Const wordBlue = 2
Private Const wordCyan = 3
Private Const wordGreen = 4
Private Const wordMagenta = 5
Private Const wordRed = 6
Private Const wordYellow = 7
Private Const wordWhite = 8
Private Const wordDarkBlue = 9
Private Const wordDarkCyan = 10
Private Const wordDarkGreen = 11
Private Const wordDarkMagenta = 12
Private Const wordDarkRed = 13
Private Const wordDarkYellow = 14
Private Const wordDarkGray = 15
Private Const wordLightGray = 16
'*********************************************************************
' The following 6 properties are used to change the colors used to
' display certain elements.
'*********************************************************************
Public Property Let clrContinueChar(iColor As Integer)
    ColorContinueChar = iColor
End Property

Public Property Let clrComment(iColor As Integer)
    ColorComment = iColor
End Property

Public Property Let clrDeclare(iColor As Integer)
    ColorDeclare = iColor
End Property

Public Property Let clrDefault(iColor As Integer)
    ColorDefault = iColor
End Property

Public Property Let clrFunction(iColor As Integer)
    ColorFunction = iColor
End Property

Public Property Let clrSub(iColor As Integer)
    ColorSub = iColor
End Property
'*********************************************************************
' Expose the Word object in case the user wants to perform additional
' file processing.
'*********************************************************************
Public Property Set GetWord(obj As Object)
    Set obj = Word
End Property
'*********************************************************************
' This property lets you set the visible state of Word.
'*********************************************************************
Public Property Let Visible(bShowWindow As Boolean)
    If bShowWindow Then
        Word.AppHide
        Word.AppShow
    Else
        Word.AppHide
    End If
End Property

Public Property Get Errors() As Integer
    Errors = ErrValue
End Property
'*********************************************************************
' Initialize all member variables.
'*********************************************************************
Private Sub Class_Initialize()
    On Error Resume Next
    frmProgress.Update 0, "Establishing a connection with Word..."
    frmProgress.Refresh
    ColorDefault = wordAutomatic
    ColorContinueChar = wordRed
    ColorFunction = wordDarkBlue
    ColorDeclare = wordDarkCyan
    ColorComment = wordDarkGreen
    SourceFile = FreeFile
    OLEConnect Word, "Word.Basic"
End Sub
'*********************************************************************
' Release the memory use by Word.
'*********************************************************************
' WARNING: If Word wasn't already running, then all changes will be
'          lost. If you want to save the changes, then you must access
'          the Word object and save them manually.
'*********************************************************************
Private Sub Class_Terminate()
    On Error Resume Next
    If bRestore Then Word.ToggleFull
    Unload frmProgress
    Set Word = Nothing
End Sub
'*********************************************************************
' Inserts a formmated copy of a VB file into Word.
'*********************************************************************
Public Sub PrettyPrint(FileName As String, Optional Header)
Dim Look$
    '*****************************************************************
    ' Change the pointer, open a new file, and print the header.
    '*****************************************************************
    On Error GoTo PrettyPrint_Err
    frmProgress.Update 0, "Initializing..."
    Screen.MousePointer = vbHourglass
    Word.FileNew Template:=App.Path & "\prettypr.dot"
    PrintHeader IIf(IsMissing(Header), FileName, Header)
    '*****************************************************************
    ' Open the file as READ ONLY, and examine every line.
    '*****************************************************************
    Open FileName For Input Access Read As SourceFile
        Do While Not EOF(SourceFile)
            Line Input #SourceFile, Look
            frmProgress.Update (Seek(SourceFile) / _
                LOF(SourceFile)) * 100, "Reading " & _
                LCase(FileName) & "..."
            ExamineLine Look
        Loop
    Close SourceFile
    
    frmProgress.Update 100, "Complete!"
    '*****************************************************************
    ' Change the margins, and view it at 90% in Normal mode.
    '*****************************************************************
    DisplayResults IIf(MsgBox( _
         "Would you like to view your results in full-screen mode?", _
         vbQuestion + vbYesNo) = vbYes, True, False)
    With Word
        .FilePageSetup TopMargin:="0.25", BottomMargin:="0.25", _
                       LeftMargin:="0.25", RightMargin:="0.25"
        .ViewNormal
        .ViewZoom ZoomPercent:="90%"
    End With
    '*****************************************************************
    ' When your done, restore the pointer and create a Word filename.
    '*****************************************************************
    DocFileName = Left(FileName, InStr(FileName, ".")) & "DOC"
    Screen.MousePointer = vbDefault
    Unload frmProgress
    Exit Sub
    
PrettyPrint_Err:
    Unload frmProgress
    MsgBox Error, vbCritical
    Screen.MousePointer = vbDefault
    ErrValue = Err
    Exit Sub
End Sub
'*********************************************************************
' This is the first line printed before the file is inserted.
'*********************************************************************
Private Sub PrintHeader(Header As String)
    '*****************************************************************
    ' Change the current font, and insert the header.
    '*****************************************************************
    ChangeFont sFont:="Arial", bBold:=1, sPoints:="14"
    With Word
        .Insert Header
        .FormatParagraph After:="6 pt"
        .InsertPara
        .FormatParagraph After:="0 pt"
    End With
End Sub
'*********************************************************************
' Determine how the line should be formatted.
'*********************************************************************
Private Sub ExamineLine(Source As String)
Dim where%
    '*****************************************************************
    ' Check for a Sub, Function, Property, and regular line,
    ' respectively.
    '*****************************************************************
    where = InStr(Source, FIND_SUB)
    If where Then
        FormatProcedure where, Source
    Else
        where = InStr(Source, FIND_FUNCTION)
        where = IIf(where, where, InStr(Source, FIND_PROPERTY))
        If where Then
            FormatProcedure where, Source
        Else
            FormatDefault Source
        End If
    End If
End Sub
'*********************************************************************
' This Procedure handles the formatting of properties, subs, and
' functions.
'*********************************************************************
Private Sub FormatProcedure(where%, Source$)
Dim CommentPresent%, DeclarePresent%
    '*****************************************************************
    ' Search for comments and external declarations.
    '*****************************************************************
    CommentPresent = InStr(Source, FIND_COMMENT)
    DeclarePresent = InStr(Source, FIND_DECLARE)
    '*****************************************************************
    ' If this line is really a Procedure and not a Exit Sub, Exit
    ' Function or API declaration, then continue.
    '*****************************************************************
    If where And InStr(Source, "Exit ") = 0 And DeclarePresent = 0 Then
        '*************************************************************
        ' Change the font.
        '*************************************************************
        ChangeFont bBold:=1, iColor:=ColorFunction
        '*************************************************************
        ' If a comment is present, then split the line for formatting.
        '*************************************************************
        If CommentPresent Then
            Word.Insert Left(Source, CommentPresent - 1)
            FormatComment CommentPresent, Source
        '*************************************************************
        ' If there is a line continuation char, then...
        '*************************************************************
        ElseIf Right(Source, 2) = FIND_CONTINUE_CHAR Then
            '*********************************************************
            ' Loop while the current line has a line continue char.
            '*********************************************************
            Do While Right(Source, 2) = FIND_CONTINUE_CHAR
                Word.Insert Left(Source, Len(Source) - 2)
                '*****************************************************
                ' Format the continuation char, so it sticks out.
                '*****************************************************
                ChangeFont bBold:=1, iColor:=ColorContinueChar
                Word.Insert Right(Source, 2)
                Word.InsertPara
                ChangeFont bBold:=1, iColor:=ColorFunction
                '*****************************************************
                ' Read the next line.
                '*****************************************************
                Line Input #SourceFile, Source
                frmProgress.Update (Seek(SourceFile) \ _
                            LOF(SourceFile)) * 100
            Loop
            Word.Insert Source
            Word.InsertPara
        Else
            Word.Insert Source
            Word.InsertPara
        End If
    '*****************************************************************
    ' If it is an external declartion, then process it.
    '*****************************************************************
    ElseIf DeclarePresent Then
        FormatDeclaration Source
    '*****************************************************************
    ' Otherwise, it must be a normal line.
    '*****************************************************************
    Else
        FormatDefault Source
    End If
End Sub
'*********************************************************************
' Formats a line with the default formatting.
'*********************************************************************
Private Sub FormatDefault(ByVal Source$)
Dim where%
    '*****************************************************************
    ' If there is a line continuation char, then loop and format each
    ' continued line.
    '*****************************************************************
    If Right(Source, 2) = FIND_CONTINUE_CHAR Then
        Do While Right(Source, 2) = FIND_CONTINUE_CHAR
            ChangeFont
            Word.Insert Left(Source, Len(Source) - 2)
            ChangeFont bBold:=1, iColor:=ColorContinueChar
            Word.Insert Right(Source, 2)
            Word.InsertPara
            Line Input #SourceFile, Source
            frmProgress.Update (Seek(SourceFile) \ _
                        LOF(SourceFile)) * 100
        Loop
        ChangeFont
        Word.Insert Source
        Word.InsertPara
    '*****************************************************************
    ' Otherwise use the default format and check for comments.
    '*****************************************************************
    Else
        ChangeFont
        where = InStr(Source, FIND_COMMENT)
        If where Then
            Word.Insert Left(Source, where - 1)
            FormatComment where, Source
        Else
            Word.Insert Source
            Word.InsertPara
        End If
    End If
End Sub
'*********************************************************************
' Formats a comment in italics.
'*********************************************************************
Private Sub FormatComment(where%, Source)
    '*****************************************************************
    ' Change the font to italics, and print the rest of the line.
    '*****************************************************************
    ChangeFont bItalic:=1, iColor:=ColorComment
    Word.Insert Mid(Source, where)
    Word.InsertPara
End Sub
'*********************************************************************
' Formats a declare statement like the default, but its colored.
'*********************************************************************
Private Sub FormatDeclaration(Source$)
Dim CommentPresent%
    '*****************************************************************
    ' Search for a comment char, and change the font.
    '*****************************************************************
    CommentPresent = InStr(Source, FIND_COMMENT)
    ChangeFont iColor:=ColorDeclare
    '*****************************************************************
    ' If a comment is present, then print up to the comment.
    '*****************************************************************
    If CommentPresent Then
        Word.Insert Left(Source, CommentPresent - 1)
        FormatComment CommentPresent, Source
    '*****************************************************************
    ' If there is a line continue char then loop and format each
    ' continued line.
    '*****************************************************************
    ElseIf Right(Source, 2) = FIND_CONTINUE_CHAR Then
        Do While Right(Source, 2) = FIND_CONTINUE_CHAR
            Word.Insert Left(Source, Len(Source) - 2)
            ChangeFont bBold:=1, iColor:=ColorContinueChar
            Word.Insert Right(Source, 2)
            Word.InsertPara
            ChangeFont iColor:=ColorDeclare
            Line Input #SourceFile, Source
            frmProgress.Update (Seek(SourceFile) \ _
                        LOF(SourceFile)) * 100
        Loop
        Word.Insert Source
        Word.InsertPara
    '*****************************************************************
    ' Otherwise, just print it with the new font settings.
    '*****************************************************************
    Else
        Word.Insert Source
        Word.InsertPara
    End If
End Sub
'*********************************************************************
' Displays Word in Full Screen Word.
'*********************************************************************
Public Sub DisplayResults(FullScreenMode As Boolean)
    '*****************************************************************
    ' Return to the start of the document.
    '*****************************************************************
    Word.StartOfDocument
    '*****************************************************************
    ' If the user wants full screen mode, then make sure the Full
    ' Screen toolbar is visible.
    '*****************************************************************
    If FullScreenMode Then
        With Word
            .ToggleFull
            .ViewToolbars Toolbar:="Full Screen", Show:=1
            .MoveToolbar "Full Screen", 5, 595, 43
        End With
        bRestore = True
    End If
    '*****************************************************************
    ' Let the system catch up, then show Word.
    '*****************************************************************
    DoEvents
    Word.AppHide
    Word.AppShow
End Sub
'*********************************************************************
' Saves the file. If no filename is provided, then a default will be
' provided by using the original name with a .DOC extension.
'*********************************************************************
Public Sub Save(Optional FileName)
    Word.FileSaveAs IIf(IsMissing(FileName), DocFileName, FileName)
End Sub
'*********************************************************************
' Prints the results of the formatting to the current printer.
'*********************************************************************
Public Sub PrintResults()
    Word.FilePrintDefault
End Sub
'*********************************************************************
' Changes the current font in Word. If an argument is ommitted, then
' a default value is used.
'*********************************************************************
Private Sub ChangeFont(Optional sPoints, Optional iColor, Optional _
                       sFont, Optional bBold, Optional bItalic)
    Word.FormatFont Points:=IIf(IsMissing(sPoints), "10", sPoints), _
                Color:=IIf(IsMissing(iColor), ColorDefault, iColor), _
                Font:=IIf(IsMissing(sFont), "Courier New", sFont), _
                Bold:=IIf(IsMissing(bBold), 0, bBold), _
                Italic:=IIf(IsMissing(bItalic), 0, bItalic)
End Sub
'*********************************************************************
' OLEConnect takes a pointer to an object variable and class name. If
' this function is successful, then the function returns true and the
' obj argument points to a valid OLE Automation object.
'*********************************************************************
Private Function OLEConnect(obj As Object, sClass As String) As Boolean
    '*****************************************************************
    ' Temporarily turn off error handling
    '*****************************************************************
    On Error Resume Next
    Set obj = GetObject(, sClass)
    '*****************************************************************
    ' If GetObject failed, then try Create
    '*****************************************************************
    If Err = 429 Then
        '*************************************************************
        ' Resume Error Handling
        '*************************************************************
        On Error GoTo OLEConnect_Err
        Set obj = CreateObject(sClass)
    '*****************************************************************
    ' If any other error, then display & exit
    '*****************************************************************
    ElseIf Err <> 0 Then
        GoSub OLEConnect_Err
    End If
    '*****************************************************************
    ' If this line is executed, then the function succeded
    '*****************************************************************
    OLEConnect = True
    Exit Function
'*********************************************************************
' Display error message and abort
'*********************************************************************
OLEConnect_Err:
    MsgBox Err.Description, vbCritical
    Exit Function
End Function

